==> ubuntuone-control-panel_4.1.90.orig.tar.gz: ubuntuone-control-panel-4.1.90/ubuntuone/controlpanel/gui/qt/tests/test_controlpanel.py <==
# -*- coding: utf-8 -*-
#
# Copyright 2011-2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Tests for the Control Panel."""

from __future__ import division

from twisted.internet import defer

from ubuntuone.controlpanel.gui.qt import controlpanel as gui
from ubuntuone.controlpanel.gui.qt.tests import (
    SAMPLE_ACCOUNT_INFO, SAMPLE_NAME,
)
from ubuntuone.controlpanel.gui.qt.tests.test_ubuntuonebin import (
    UbuntuOneBinTestCase,
)

# pylint: disable=W0212


class ControlPanelTestCase(UbuntuOneBinTestCase):
    """Test the qt control panel."""

    innerclass_ui = gui.controlpanel_ui
    innerclass_name = "Ui_Form"
    class_ui = gui.ControlPanel

    @defer.inlineCallbacks
    def test_is_processing_while_asking_info(self):
        """The ui is processing while the contents are loaded."""
        def check():
            """The ui must be is_processing."""
            self.assertTrue(self.ui.is_processing, 'ui must be processing')
            return {}

        self.patch(self.ui.backend, 'get_credentials', check)

        yield self.ui.load()  # trigger the info request
        self.assertFalse(self.ui.is_processing, 'ui must not be processing')

    @defer.inlineCallbacks
    def test_credentials_are_requested_on_load(self):
        """The info is requested to the backend."""
        yield self.ui.load()
        self.assert_backend_called('get_credentials')

    @defer.inlineCallbacks
    def test_on_credentials_not_found_called(self):
        """If no credentials, on_credentials_not_found is called."""
        self.patch(self.ui, 'on_credentials_not_found', self._set_called)
        self.patch(self.ui.backend, 'get_credentials', lambda: {})
        yield self.ui.load()

        self.assertEqual(self._called, ((), {}))

    def test_on_credentials_not_found(self):
        """The wizard panel is shown."""
        self.patch(self.ui.ui.wizard, 'restart', self._set_called)
        self.ui.on_credentials_found()
        self.ui.on_credentials_not_found()
        self.assertIs(self.ui.ui.switcher.currentWidget(), self.ui.ui.wizard)
        self.assertEqual(self._called, ((), {}))

    def test_on_credentials_not_found_sets_folder_tab(self):
        """Credentials_not_found should switch to the folder tab."""
        unexpected = self.ui.ui.tab_widget.indexOf(self.ui.ui.devices_tab)
        expected = self.ui.ui.tab_widget.indexOf(self.ui.ui.folders_tab)
        self.ui.ui.tab_widget.setCurrentIndex(unexpected)
        self.ui.on_credentials_not_found()
        self.assertEqual(self.ui.ui.tab_widget.currentIndex(), expected)

    @defer.inlineCallbacks
    def test_on_credentials_found_called(self):
        """If credentials, on_credentials_not_found is called."""
        self.patch(self.ui, 'on_credentials_found', self._set_called)
        yield self.ui.load()

        self.assertEqual(self._called, ((), {}))

    def test_on_credentials_found(self):
        """File sync is connected and the management panel is shown."""
        self.patch(self.ui, 'connect_file_sync', self._set_called)
        yield self.ui.on_credentials_found()

        self.assertIs(self.ui.ui.switcher.currentWidget(),
                      self.ui.ui.management)
        self.assertEqual(self._called, ((), {}))

    @defer.inlineCallbacks
    def test_info_is_requested_on_load(self):
        """The info is requested to the backend."""
        self.patch(self.ui, 'process_info', self._set_called)
        yield self.ui.load()
        self.assert_backend_called('account_info')
        self.assertEqual(self._called, ((SAMPLE_ACCOUNT_INFO,), {}))

    def test_process_info(self):
        """The info is processed when ready."""
        info = SAMPLE_ACCOUNT_INFO
        self.ui.process_info(info)

        name = gui.NAME_STYLE % SAMPLE_NAME
        greeting = gui.GREETING % {'user_display_name': name}
        self.assertEqual(unicode(self.ui.ui.greeting_label.text()), greeting)

        used = int(info['quota_used'])
        total = int(info['quota_total'])
        percentage = round((used / total) * 100, 2)
        percentage_usage = {'percentage': gui.PERCENTAGE_STYLE % percentage}
        expected = {'used': gui.humanize(used),
                    'total': gui.humanize(total)}
        msg = gui.USAGE_LABEL % expected
        self.assertEqual(unicode(self.ui.ui.quota_usage_label.text()), msg)
        msg = gui.PERCENTAGE_LABEL % percentage_usage
        self.assertEqual(unicode(self.ui.ui.percentage_usage_label.text()),
            msg)

    def test_update_over_quota(self):
        """Check the labels state when the user exceed the quota."""
        self.ui._update_quota(True)

        self.assertTrue(
            self.ui.ui.percentage_usage_label.property("OverQuota").toBool())
        self.assertTrue(
            self.ui.ui.quota_usage_label.property("OverQuota").toBool())

    def test_update_quota_in_range(self):
        """Check the labels state when the quota is under the threshold."""
        self.ui._update_quota(False)

        self.assertFalse(
            self.ui.ui.percentage_usage_label.property("OverQuota").toBool())
        self.assertFalse(
            self.ui.ui.quota_usage_label.property("OverQuota").toBool())

    def test_on_local_device_removed(self):
        """On DeviesPanel's localDeviceRemoved, emit credentialsNotFound."""
        self.ui.ui.devices_tab.localDeviceRemoved.emit()
        self.assertIs(self.ui.ui.switcher.currentWidget(), self.ui.ui.wizard)

    def test_on_wizard_finished(self):
        """When the wizard is finished, the management panel is shown."""
        self.patch(self.ui, 'show_management_ui', self._set_called)
        self.ui.ui.wizard.finished.emit(1)

        self.assertEqual(self._called, ((), {}))

    def test_on_wizard_rejected(self):
        """When the wizard is cancelled, the finished signal is emitted."""
        self.ui.finished.connect(self._set_called)
        self.ui.ui.wizard.rejected.emit()

        self.assertEqual(self._called, ((), {}))

    @defer.inlineCallbacks
    def test_connect_file_sync_with_autoconnect(self):
        """Connect is called if autoconnect is enabled."""
        settings = {gui.AUTOCONNECT_KEY: True}
        self.patch(self.ui.backend, 'file_sync_settings_info',
                   lambda: defer.succeed(settings))

        yield self.ui.connect_file_sync()

        self.assert_backend_called('connect_files')

    @defer.inlineCallbacks
    def test_connect_file_sync_without_autoconnect(self):
        """Connect is called if autoconnect is disabled."""
        self.ui.backend._called.clear()
        settings = {gui.AUTOCONNECT_KEY: False}
        self.patch(self.ui.backend, 'file_sync_settings_info',
                   lambda: defer.succeed(settings))

        yield self.ui.connect_file_sync()

        self.assertNotIn('connect_files', self.ui.backend._called)

    def test_folder_panel_shows_all_folders(self):
        """The FolderPanel shows all folders (not remote only)."""
        remote = self.ui.ui.folders_tab.remote_folders
        self.assertFalse(remote)

    def test_start_from_license(self):
        """Ensure we change the starting page correctly."""
        # Before, we start on sign_in
        self.assertEqual(self.ui.ui.wizard.startId(),
            self.ui.ui.wizard.pages[self.ui.ui.wizard.signin_page])
        # After, we start on license_page
        self.ui.start_from_license()
        self.assertEqual(self.ui.ui.wizard.startId(),
            self.ui.ui.wizard.pages[self.ui.ui.wizard.license_page])


class ExternalLinkButtonsTestCase(ControlPanelTestCase):
    """The link in the go-to-web buttons are correct."""

    def test_get_more_space_button(self):
        """When clicking the get more GB button, the proper url is opened."""
        self.assert_uri_hook_called(self.ui.ui.get_more_space_button,
                                    gui.GET_STORAGE_LINK)

    def test_help_button(self):
        """When clicking the help button, the proper url is opened."""
        self.assert_uri_hook_called(self.ui.ui.help_button,
                                    gui.GET_SUPPORT_LINK)

    def test_twitter_button(self):
        """When clicking the twitter button, the proper url is opened."""
        self.assert_uri_hook_called(self.ui.ui.twitter_button,
                                    gui.TWITTER_LINK)

    def test_facebook_button(self):
        """When clicking the facebook button, the proper url is opened."""
        self.assert_uri_hook_called(self.ui.ui.facebook_button,
                                    gui.FACEBOOK_LINK)

==> ubuntuone-control-panel_13.09.orig.tar.gz: ubuntuone-control-panel-13.09/ubuntuone/controlpanel/gui/qt/tests/test_controlpanel.py <==
# -*- coding: utf-8 -*-
#
# Copyright 2011-2013 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Tests for the Control Panel."""

from __future__ import division

from twisted.internet import defer
from PyQt4 import QtCore

from ubuntuone.controlpanel import backend, cache
from ubuntuone.controlpanel.tests import TestCase
from mock import call, Mock

from ubuntuone.controlpanel.gui.qt import share_links

from ubuntuone.controlpanel.gui.qt import controlpanel as gui
from ubuntuone.controlpanel.gui.qt.tests import (
    FakedControlPanelBackend, SAMPLE_ACCOUNT_INFO, SAMPLE_NAME,
)
from ubuntuone.controlpanel.gui.qt.tests.test_ubuntuonebin import (
    UbuntuOneBinTestCase,
)

# pylint: disable=W0212


class ControlPanelTestCase(UbuntuOneBinTestCase):
    """Test the qt control panel."""

    innerclass_ui = gui.controlpanel_ui
    innerclass_name = "Ui_Form"
    class_ui = gui.ControlPanel

    @defer.inlineCallbacks
    def test_is_processing_while_asking_info(self):
        """The ui is processing while the contents are loaded."""
        def check():
            """The ui must be is_processing."""
            self.assertTrue(self.ui.is_processing, 'ui must be processing')
            return {}

        self.patch(self.ui.backend, 'get_credentials', check)

        yield self.ui.load()  # trigger the info request
        self.assertFalse(self.ui.is_processing, 'ui must not be processing')

    @defer.inlineCallbacks
    def test_credentials_are_requested_on_load(self):
        """The info is requested to the backend."""
        yield self.ui.load()
        self.assert_backend_called('get_credentials')

    @defer.inlineCallbacks
    def test_on_credentials_not_found_called(self):
        """If no credentials, on_credentials_not_found is called."""
        self.patch(self.ui, 'on_credentials_not_found', self._set_called)
        self.patch(self.ui.backend, 'get_credentials', lambda: {})
        yield self.ui.load()

        self.assertEqual(self._called, ((), {}))

    def test_on_credentials_not_found(self):
        """The wizard panel is shown."""
        self.patch(self.ui.ui.wizard, 'restart', self._set_called)
        self.ui.on_credentials_found()
        self.ui.on_credentials_not_found()
        self.assertIs(self.ui.ui.switcher.currentWidget(), self.ui.ui.wizard)
        self.assertEqual(self._called, ((), {}))

    def test_on_credentials_not_found_sets_folder_tab(self):
        """Credentials_not_found should switch to the folder tab."""
        unexpected = self.ui.ui.tab_widget.indexOf(self.ui.ui.devices_tab)
        expected = self.ui.ui.tab_widget.indexOf(self.ui.ui.folders_tab)
        self.ui.ui.tab_widget.setCurrentIndex(unexpected)
        self.ui.on_credentials_not_found()
        self.assertEqual(self.ui.ui.tab_widget.currentIndex(), expected)

    @defer.inlineCallbacks
    def test_on_credentials_found_called(self):
        """If credentials, on_credentials_not_found is called."""
        self.patch(self.ui, 'on_credentials_found', self._set_called)
        yield self.ui.load()

        self.assertEqual(self._called, ((), {}))

    def test_on_credentials_found(self):
        """File sync is connected and the management panel is shown."""
        self.patch(self.ui, 'connect_file_sync', self._set_called)
        yield self.ui.on_credentials_found()

        self.assertIs(self.ui.ui.switcher.currentWidget(),
                      self.ui.ui.management)
        self.assertEqual(self._called, ((), {}))

    @defer.inlineCallbacks
    def test_info_is_requested_on_load(self):
        """The info is requested to the backend."""
        self.patch(self.ui, 'process_info', self._set_called)
        yield self.ui.load()
        self.assert_backend_called('account_info')
        self.assertEqual(self._called, ((SAMPLE_ACCOUNT_INFO,), {}))

    def test_process_info(self):
        """The info is processed when ready."""
        info = SAMPLE_ACCOUNT_INFO
        self.ui.process_info(info)

        name = gui.NAME_STYLE % SAMPLE_NAME
        greeting = gui.GREETING % {'user_display_name': name}
        self.assertEqual(unicode(self.ui.ui.greeting_label.text()), greeting)

        used = int(info['quota_used'])
        total = int(info['quota_total'])
        percentage = round((used / total) * 100, 2)
        percentage_usage = {'percentage': gui.PERCENTAGE_STYLE % percentage}
        expected = {'used': gui.humanize(used),
                    'total': gui.humanize(total)}
        msg = gui.USAGE_LABEL % expected
        self.assertEqual(unicode(self.ui.ui.quota_usage_label.text()), msg)
        msg = gui.PERCENTAGE_LABEL % percentage_usage
        self.assertEqual(unicode(self.ui.ui.percentage_usage_label.text()),
            msg)

    def test_update_over_quota(self):
        """Check the labels state when the user exceed the quota."""
        self.ui._update_quota(True)

        self.assertTrue(
            self.ui.ui.percentage_usage_label.property("OverQuota").toBool())
        self.assertTrue(
            self.ui.ui.quota_usage_label.property("OverQuota").toBool())

    def test_update_quota_in_range(self):
        """Check the labels state when the quota is under the threshold."""
        self.ui._update_quota(False)

        self.assertFalse(
            self.ui.ui.percentage_usage_label.property("OverQuota").toBool())
        self.assertFalse(
            self.ui.ui.quota_usage_label.property("OverQuota").toBool())

    def test_on_local_device_removed(self):
        """On DeviesPanel's localDeviceRemoved, emit credentialsNotFound."""
        self.ui.ui.devices_tab.localDeviceRemoved.emit()
        self.assertIs(self.ui.ui.switcher.currentWidget(), self.ui.ui.wizard)

    def test_on_wizard_finished(self):
        """When the wizard is finished, the management panel is shown."""
        self.patch(self.ui, 'show_management_ui', self._set_called)
        self.ui.ui.wizard.finished.emit(1)

        self.assertEqual(self._called, ((), {}))

    def test_on_wizard_rejected(self):
        """When the wizard is cancelled, the finished signal is emitted."""
        self.ui.finished.connect(self._set_called)
        self.ui.ui.wizard.rejected.emit()

        self.assertEqual(self._called, ((), {}))

    @defer.inlineCallbacks
    def test_connect_file_sync_with_autoconnect(self):
        """Connect is called if autoconnect is enabled."""
        settings = {gui.AUTOCONNECT_KEY: True}
        self.patch(self.ui.backend, 'file_sync_settings_info',
                   lambda: defer.succeed(settings))

        yield self.ui.connect_file_sync()

        self.assert_backend_called('connect_files')

    @defer.inlineCallbacks
    def test_connect_file_sync_without_autoconnect(self):
        """Connect is called if autoconnect is disabled."""
        self.ui.backend._called.clear()
        settings = {gui.AUTOCONNECT_KEY: False}
        self.patch(self.ui.backend, 'file_sync_settings_info',
                   lambda: defer.succeed(settings))

        yield self.ui.connect_file_sync()

        self.assertNotIn('connect_files', self.ui.backend._called)

    def test_folder_panel_shows_all_folders(self):
        """The FolderPanel shows all folders (not remote only)."""
        remote = self.ui.ui.folders_tab.remote_folders
        self.assertFalse(remote)

    def test_start_from_license(self):
        """Ensure we change the starting page correctly."""
        # Before, we start on sign_in
        self.assertEqual(self.ui.ui.wizard.startId(),
            self.ui.ui.wizard.pages[self.ui.ui.wizard.signin_page])
        # After, we start on license_page
        self.ui.start_from_license()
        self.assertEqual(self.ui.ui.wizard.startId(),
            self.ui.ui.wizard.pages[self.ui.ui.wizard.license_page])


class ControlPanelConnectionTestCase(TestCase):
    """Test qt signal connections from controlpanel."""

    @defer.inlineCallbacks
    def setUp(self):
        cache.Cache._shared_objects = {}
        yield super(ControlPanelConnectionTestCase, self).setUp()
        self.patch(backend, 'ControlBackend', FakedControlPanelBackend)

        self.mock_handler = Mock(name='handle_current_tab_changed')
        self.patch(share_links.ShareLinksPanel, 'handle_current_tab_changed',
                   self.mock_handler)

        self.ui = gui.ControlPanel()
        self.ui.show()
        self.addCleanup(self.ui.hide)
        #self.addCleanup(self.ui.deleteLater)
        self.addCleanup(QtCore.QCoreApplication.instance().processEvents)

        if getattr(self.ui, 'backend', None) is not None:
            self.addCleanup(self.ui.backend._called.clear)

    def test_popup_hides_when_switching_tab(self):
        """Test that the share_links_tab gets the signal for changed tabs"""
        folders_index = self.ui.ui.tab_widget.indexOf(self.ui.ui.folders_tab)
        share_index = self.ui.ui.tab_widget.indexOf(self.ui.ui.share_links_tab)
        self.ui.ui.tab_widget.setCurrentIndex(share_index)
        self.ui.ui.tab_widget.setCurrentIndex(folders_index)

        self.assertEqual(self.mock_handler.mock_calls,
                         [call(share_index), call(folders_index)])


class ExternalLinkButtonsTestCase(ControlPanelTestCase):
    """The link in the go-to-web buttons are correct."""

    def test_get_more_space_button(self):
        """When clicking the get more GB button, the proper url is opened."""
        self.assert_uri_hook_called(self.ui.ui.get_more_space_button,
                                    gui.GET_STORAGE_LINK)

    def test_help_button(self):
        """When clicking the help button, the proper url is opened."""
        self.assert_uri_hook_called(self.ui.ui.help_button,
                                    gui.GET_SUPPORT_LINK)

    def test_twitter_button(self):
        """When clicking the twitter button, the proper url is opened."""
        self.assert_uri_hook_called(self.ui.ui.twitter_button,
                                    gui.TWITTER_LINK)

    def test_facebook_button(self):
        """When clicking the facebook button, the proper url is opened."""
        self.assert_uri_hook_called(self.ui.ui.facebook_button,
                                    gui.FACEBOOK_LINK)
